import java.awt.*;
import javax.swing.*;
import java.awt.event.*;
import java.applet.*;
import java.lang.*;
import java.util.*;
import com.borland.jbcl.layout.*;
import javax.swing.border.*;
/**
 * Title:         GameArea.java
 * Description:   Abstract GameArea class.
 * Copyright:     Annemari Auvinen, Anu Niemi (c) 2001
 * Company:
 * @author        Annemari Auvinen, Anu Niemi
 * @version 1.0
 *
 * @param   bottom    Int value of limit to which the next bar can be moved.
 * @param   bars      Vector for Bar objects.
 * @param   tasks     Vector for Task objects.
 * @param   isEndGame Boolean value which indicates whether the game is ended or not.
 */

public abstract class GameArea extends JComponent{
  private int bottom;
  protected Vector bars = new Vector();
  protected Vector tasks = new Vector();
  private boolean isEndGame;
  XYLayout xYLayout1 = new XYLayout();

/**
 * Constructor for GameArea.
 */
  public GameArea() {
    try {
      this.setBackground(Color.white); //Does not work.
      isEndGame=false;
      jbInit();
    } catch(Exception ex) {
      ex.printStackTrace();
    }
  }

  void jbInit() throws Exception {
    this.setBackground(SystemColor.control);
    this.setLayout(xYLayout1);
  }

/**
 * Overrided method for drawing. Draws the bars into game area.
 * @param  g  Graphics object.
 */
  public void paintComponent(Graphics g)
  {
    super.paintComponent(g);
    if (bars.size()<1)
      return;
    for (int j=0; j<bars.size(); j++)
    {
      Bar bar = (Bar)bars.elementAt(j);
      bar.setSize(this.getWidth(), 30);  //Tried to set height related to the height of the game area, didn't succeed.
      if(bars.size() > 1 && j != bars.size()-1) {
        bar.setLocation(bar.getX(),this.getHeight()-(j+1)*bar.getHeight());
      }
    }
    Bar bar = (Bar)bars.elementAt(0);
    bottom = this.getHeight()-(bars.size()*bar.getHeight());
  }
/**
 * Destroyes all bars and tasks and creates a new bar and task.
 */

  public void newGame()
  {
    bars.clear();
    this.removeAll();
    tasks.clear();
    this.repaint();
    createNewTask();
    isEndGame=false;
  }
/**
 * Moves the most recently created bar.
 * If the bottom is reached a new bar and task is created.
 * If there is not enough space for a new bar the EndGame exception is thrown.
 * @exception EndGame     If there is not enough space for a new bar the EndGame
 *                        exception is thrown.
 */
  public void move() throws EndGame
  {
    if (bars.size()>0)
    {
      Bar bar = (Bar)bars.elementAt(bars.size()-1);
      if (bar.getY()+bar.getHeight() < bottom)
      {
        bar.setLocation(bar.getX(), bar.getY()+ bar.getHeight());
      } else {
        bar.setLocation(bar.getX(),bottom);
        createNewTask();
      }
      if(bottom < bar.getHeight()) {
        bar.setLocation(bar.getX(),bottom);
        isEndGame=true;
        throw new EndGame("Game over");
      }
      repaint();
    }
  }
/**
 * Checks whether the parameter answer is the right answer to the given task.
 * @param answer   String to check.
 * @return         Boolean which indicates whether the answer was right or not.
 */
  public boolean isAnswerRight(String answer) {
   if (tasks.size()<1)
     return false;
   Task task = (Task)tasks.elementAt(tasks.size()-1);
   return task.isAnswerRight(answer);

  }

/**
 * Method deletes the moving bar.
 */
  public void deleteBar()
  {
    Component comp = (Component)bars.elementAt(bars.size()-1);
    bars.remove(bars.size()-1);
    this.remove(comp);
    this.repaint();
  }

/**
 *Returns the value of parameter isEndGame.
 *@return   Boolean value, which is true if the game is ended and false otherwise.
 */

  public boolean getIsEndGame()
  {
    return isEndGame;
  }
/**
 * Abstract method for creating a new task.
 */
  public abstract void createNewTask();

}
