import java.util.*;
import java.io.*;
import javax.mail.*;
import javax.mail.internet.*;
import javax.activation.*;
import java.awt.*;
import javax.swing.*;


/**
 * Title:       MailSender.java
 * Description: Class for sending an email.
 * Copyright:   Annemari Auvinen, Anu Niemi(c) 2001
 * Company:
 * @author      Annemari Auvinen, Anu Niemi
 * @version     1.0
 *
 * @param   to    String value, which is the email address to which the email is sent.
 */

public class MailSender {
  private String to = "anniemi@st.jyu.fi";
  Properties props = new Properties();

/**
 * Constructor for the MailSender.
 */
  public MailSender() {
  }
/**
 * Handles mail sending. Shows the error message if sending didn't succeed.
 * @param   from     String value, which is sender's address.
 * @param   host     String value, which is the used protocol.
 * @param   msgText  String value, which is the message to sent.
 * @param   errorMsg String error text which is shown if sending didn't succeed.
 *  @return        Boolean value, which is true if sending succeed and false, if not.
 */
  public boolean sendMail(String from,String host,String msgText, String errorMsg) {
    boolean debug = false;
    props.put("mail.smtp.host", host);
    if (debug)
      props.put("mail.debug", host);
    Session session = Session.getDefaultInstance(props, null);
    session.setDebug(debug);

    try {
      Message msg = new MimeMessage(session);
      msg.setFrom(new InternetAddress(from));
      InternetAddress[] address = {new InternetAddress(to)};
      msg.setRecipients(Message.RecipientType.TO, address);
      msg.setSubject("Palautetta Matikka-pelist");
      msg.setSentDate(new Date());
      msg.setText(msgText);
      Transport.send(msg);
      return true;
    } catch (MessagingException mex) {
      Frame frame = new Frame();
      JOptionPane.showMessageDialog(frame,errorMsg);
      return false;
    }
  }

}