

/**
 * Title:        Mover.java
 * Description:  Mover class is extended from Thread and it handles the movement
 *               of the bar.
 * Copyright:    Annemari Auvinen, Anu Niemi (c) 2001
 * Company:
 * @author       Annemari Auvinen, Anu Niemi
 * @version      1.0
 *
 * @param   speed   The int value, which indicates the speed of the movement.
 * @param   area    The GameArea object, where the bar is moved.
 * @param   game    The MathGame object.
 */

public class Mover extends Thread{
  private int speed;
  private GameArea area;
  private MathGame game;

/**
 * Constructor for the Mover.
 * @param   speed   The int value, which indicates the speed of the movement.
 * @param   area    The GameArea object, where the bar is moved.
 * @param   game    The MathGame object.
 */
  public Mover(int speed, GameArea area, MathGame game) {
    this.speed = speed;
    this.area= area;
    this.game = game;
  }

/**
 *  Moves the bar until the game is over.
 */
  public void run()
  {
    while(!this.interrupted())
    {
      try {
        sleep(speed);
        area.move();
      } catch (Exception e) {
        if (area.getIsEndGame())
          game.endGame();
        return;
      }
    }
  }
/**
 * Sets the speed for mover
 * @param   speed   The int value, which indicates the speed of the movement.
 */
   public void setSpeed(int speed)
   {
     this.speed = speed;
   }
}