import java.lang.*;
import java.util.*;

/**
 * Title:        NumberTask.java
 * Description:  Task class for numerical game.
 * Copyright:    Annemari Auvinen, Anu Niemi (c) 2001
 * Company:
 * @author       Annemari Auvinen, Anu Niemi
 * @version      1.0
 *
 * @param   oMin          Int value, which indicates the minimun value for random,
 *                        which indicates the mathematical operator.
 * @param   oMax          Int value, which indicates the maximum value for random,
 *                        which indicates the mathematical operator.
 * @param   max           Maximum int value which is used in the task.
 * @param   onlyPos       Boolean value, which is true, if answer of the task
 *                        should be positive.
 * @param   number1       Int value, which is the first number of the task.
 * @param   number2       Int value, which is the second number of the task.
 * @param   prob          Char value, which indicates the operator of the task.
 * @param   answerNumber  Int value, which is the result of the task.
 */

public class NumberTask extends Task{
  private int max;
  private char prob;
  private int number1;
  private int number2;
  private int answerNumber;
  private int oMin;
  private int oMax;
  private boolean onlyPos;

/**
 * Constructor for the NumberTask.
 * @param   oMin          Int value, which indicates the minimun value for random,
 *                        which indicates the mathematical operator.
 * @param   oMax          Int value, which indicates the maximum value for random,
 *                        which indicates the mathematical operator.
 * @param   max           Maximum int value which is used in the task.
 * @param   onlyPos       Boolean value, which is true, if answer of the task
 *                        should be positive.
 */

  public NumberTask(int oMin, int oMax, int max, boolean onlyPos) {
    super();
    this.oMin = oMin;
    this.oMax = oMax;
    this.max = max;
    this.onlyPos = onlyPos;
 }
/**
 * Creates a new task.
 */
 public void newTask() {
  Random nbr = new Random();
  char Operator[] = new char[4];
  Operator[0]='+';
  Operator[1]='-';
  Operator[2]= '*';
  Operator[3]= '/';
  number1 = nbr.nextInt(max)+1;
  number2 =  nbr.nextInt(max)+1;
  int i;
  prob = Operator[randomOperator(oMin,oMax)];
  switch(prob) {
    case '+' :
      answerNumber = number1 + number2;
      break;
    case '-' :
      if((onlyPos) && (number1 < number2)) {
         i = number1;
         number1 = number2;
         number2 = i;
      }
      answerNumber = number1 - number2;
      break;
    case '*' :
      answerNumber = number1 * number2;
      break;
    case '/':
      answerNumber = number1 * number2;
      i = answerNumber;
      answerNumber = number1;
      number1 = i;
      break;
  }
    setAnswer(Integer.toString(answerNumber));
    setProblem(Integer.toString(number1) + prob + Integer.toString(number2)+ " = ");
 }

/**
 * Generates the random number between the minimun and maximum values.
 * @param   minimum   Minimum int value.
 * @param   maximum   Maximum int value.
 * @return            Int random value between the minimun and maximum values.
 */
  public int randomOperator(int minimum, int maximum) {
    Random random = new Random();
    return (random.nextInt(maximum-minimum+1)+minimum);
  }




}